@@ -10,7 +10,14 @@ set.seed(100L)
 
 lambda <- msgl.lambda.seq(x, classes, alpha = .5, d = 25L, lambda.min = 0.05, standardize = TRUE)
 
-fit.cv <- msgl.cv(x, classes, alpha = .5, fold = 11L, lambda = lambda, standardize = TRUE, max.threads = 2L)
+if(sgl.c.config()$omp.supported) {
+	threads = 2L
+} else {
+	threads = 1L
+}
+
+# This should show a warning
+fit.cv <- msgl.cv(x, classes, alpha = .5, fold = 11L, lambda = lambda, standardize = TRUE, max.threads = threads)
 
 err.count <- colSums(fit.cv$classes != classes)
 
